@@ -29,7 +29,45 @@ class Utilities(object):
         endpoint = endpoint
 
         requests.request("GET", endpoint, headers=functionalParm.getHeader("defaultUser"))
+    
+    
+    def check_status_code_turbo(self,
+                          endPoint=None,
+                          requestMethod="GET",
+                          user="Captain_America",
+                          params=None,
+                          expectedStatusCode=requests.codes.ok,
+                          jsonPayload=None,
+                          token=None):
+        if token!= None:
+            headers = {'Content-Type': 'application/json',
+                      'X-Zeta-AuthToken': token}
+        elif user == "userAuthToken":
+            headers = functionalParm.getHeaderClearRateLImit(user)
+        elif user == "userStaticToken":
+            headers = functionalParm.getTokenCardApplication(user)
+        elif user == "user3":
+            headers = header.createIDHeaders()
+        elif user == "UpdateStatusUser":
+            headers = header.updateStatusHeaders()
+        elif user == "ganymedeUser":
+            headers = header.ganymedeHeaders()
+        elif user != 'null':
+            headers = functionalParm.getHeader(user)
+        else:
+            headers = None
 
+        if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
+            endpoint = endPoint.replace("ifi/151613", "fi/13")
+        response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        logger.info(f"status code{response.status_code}")
+        assert response.status_code == expectedStatusCode, \
+            f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
+        logger.info(response.json())
+        return response
+        pass
+        
+        
     def check_status_code(self,
                           endPoint=None,
                           requestMethod="GET",
